@@ -1,6 +1,6 @@
 package Pcore::Src::Filter::HTML;
 
-use Pcore -class;
+use Pcore -class, -try;
 use Pcore::Util::Text qw[trim];
 use Pcore::Src::Filter::JS;
 use Pcore::Src::Filter::CSS;
